climind.data\_manager package
=============================

Submodules
----------

climind.data\_manager.metadata module
-------------------------------------

.. automodule:: climind.data_manager.metadata
   :members:
   :undoc-members:
   :show-inheritance:

climind.data\_manager.processing module
---------------------------------------

.. automodule:: climind.data_manager.processing
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: climind.data_manager
   :members:
   :undoc-members:
   :show-inheritance:
